/// <reference types="node" />
import _ from 'lodash';
import { Environment } from 'nunjucks';
import { EventEmitter } from 'events';
import { getProvider } from '../provider';
import { ArtifactConfig, CommandConfig, PossibleNodeConfigType, RemoteSnippet, SimpleNodeConfig } from '../types';
declare type ThenArg<T> = T extends PromiseLike<infer U> ? U : T;
export interface ArtifactOptions {
    readonly remoteSnippetList?: ReadonlyArray<RemoteSnippet>;
    readonly templateEngine?: Environment;
}
export interface ExtendableRenderContext {
    readonly urlParams?: Record<string, string>;
}
export declare class Artifact extends EventEmitter {
    surgioConfig: CommandConfig;
    artifact: ArtifactConfig;
    private options;
    initProgress: number;
    providerNameList: ReadonlyArray<string>;
    nodeConfigListMap: Map<string, ReadonlyArray<PossibleNodeConfigType>>;
    providerMap: Map<string, ThenArg<ReturnType<typeof getProvider>>>;
    nodeList: PossibleNodeConfigType[];
    nodeNameList: SimpleNodeConfig[];
    private customFilters;
    private netflixFilter;
    private youtubePremiumFilter;
    constructor(surgioConfig: CommandConfig, artifact: ArtifactConfig, options?: ArtifactOptions);
    get isReady(): boolean;
    getRenderContext(extendRenderContext?: ExtendableRenderContext): {
        clashProxyConfig?: {
            proxies: readonly any[];
            'proxy-groups': readonly any[];
        } | undefined;
        proxyTestUrl: string | undefined;
        downloadUrl: string;
        snippet: (filePath: string) => RemoteSnippet;
        nodes: PossibleNodeConfigType[];
        names: SimpleNodeConfig[];
        remoteSnippets: _.Dictionary<RemoteSnippet>;
        nodeList: PossibleNodeConfigType[];
        provider: string;
        providerName: string;
        artifactName: string;
        getDownloadUrl: (name: string) => string;
        getUrl: (p: string) => string;
        getNodeNames: (list: readonly SimpleNodeConfig[], filter?: import("../types").SortedNodeNameFilterType | import("../types").NodeNameFilterType | undefined, separator?: string | undefined) => string;
        getClashNodeNames: (list: readonly SimpleNodeConfig[], filter?: import("../types").SortedNodeNameFilterType | import("../types").NodeNameFilterType | undefined, existingProxies?: readonly string[] | undefined) => readonly string[];
        getClashNodes: (list: readonly PossibleNodeConfigType[], filter?: import("../types").SortedNodeNameFilterType | import("../types").NodeFilterType | undefined) => readonly any[];
        getSurgeNodes: (list: readonly PossibleNodeConfigType[], filter?: import("../types").SortedNodeNameFilterType | import("../types").NodeFilterType | undefined) => string;
        getSurfboardNodes: (list: readonly PossibleNodeConfigType[], filter?: import("../types").SortedNodeNameFilterType | import("../types").NodeFilterType | undefined) => string;
        getShadowsocksNodes: (list: readonly import("../types").ShadowsocksNodeConfig[], groupName?: string) => string;
        getShadowsocksNodesJSON: (list: readonly import("../types").ShadowsocksNodeConfig[]) => string;
        getShadowsocksrNodes: (list: readonly import("../types").ShadowsocksrNodeConfig[], groupName: string) => string;
        getQuantumultNodes: (list: readonly (import("../types").VmessNodeConfig | import("../types").HttpsNodeConfig | import("../types").ShadowsocksNodeConfig | import("../types").ShadowsocksrNodeConfig)[], groupName?: string, filter?: import("../types").SortedNodeNameFilterType | import("../types").NodeNameFilterType | undefined) => string;
        getV2rayNNodes: (list: readonly import("../types").VmessNodeConfig[]) => string;
        getQuantumultXNodes: (list: readonly PossibleNodeConfigType[], filter?: import("../types").SortedNodeNameFilterType | import("../types").NodeNameFilterType | undefined) => string;
        getMellowNodes: (list: readonly (import("../types").VmessNodeConfig | import("../types").ShadowsocksNodeConfig)[], filter?: import("../types").SortedNodeNameFilterType | import("../types").NodeFilterType | undefined) => string;
        getLoonNodes: (list: readonly PossibleNodeConfigType[], filter?: import("../types").SortedNodeNameFilterType | import("../types").NodeNameFilterType | undefined) => string;
        usFilter: import("../types").NodeNameFilterType;
        hkFilter: import("../types").NodeNameFilterType;
        japanFilter: import("../types").NodeNameFilterType;
        koreaFilter: import("../types").NodeNameFilterType;
        singaporeFilter: import("../types").NodeNameFilterType;
        taiwanFilter: import("../types").NodeNameFilterType;
        chinaBackFilter: import("../types").NodeNameFilterType;
        chinaOutFilter: import("../types").NodeNameFilterType;
        shadowsocksFilter: import("../types").NodeNameFilterType;
        shadowsocksrFilter: import("../types").NodeNameFilterType;
        vmessFilter: import("../types").NodeNameFilterType;
        v2rayFilter: import("../types").NodeNameFilterType;
        snellFilter: import("../types").NodeNameFilterType;
        httpFilter: import("../types").NodeNameFilterType;
        httpsFilter: import("../types").NodeNameFilterType;
        trojanFilter: import("../types").NodeNameFilterType;
        socks5Filter: import("../types").NodeNameFilterType;
        toUrlSafeBase64: (str: string) => string;
        toBase64: (str: string) => string;
        encodeURIComponent: typeof encodeURIComponent;
        netflixFilter: NonNullable<import("../types").SortedNodeNameFilterType | import("../types").NodeNameFilterType | undefined>;
        youtubePremiumFilter: NonNullable<import("../types").SortedNodeNameFilterType | import("../types").NodeNameFilterType | undefined>;
        customFilters: {
            readonly [name: string]: import("../types").SortedNodeNameFilterType | import("../types").NodeNameFilterType;
        };
        customParams: import("../types").PlainObjectOf<string | number | boolean> & Record<string, string>;
    };
    init({ requestUserAgent, }?: {
        requestUserAgent?: string;
    }): Promise<this>;
    render(templateEngine?: Environment, extendRenderContext?: ExtendableRenderContext): string;
    private providerMapper;
}
export {};
